@@ -1,17 +1,12 @@
 package Bio::Tradis::AddTagsToSeq;
-$Bio::Tradis::AddTagsToSeq::VERSION = '1.4.3';
-# ABSTRACT: Takes a BAM file and creates a new BAM with tr and tq tags added to the sequence and quality strings.
+
+# ABSTRACT: Add tags to the start of the sequences
 
 
 use Moose;
 use Bio::Seq;
 use Bio::Tradis::Parser::Bam;
-use File::Basename;
 
-no warnings qw(uninitialized);
-
-has 'verbose' => ( is => 'rw', isa => 'Bool', default => 0 );
-has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 has 'bamfile' => ( is => 'rw', isa => 'Str', required => 1 );
 has 'outfile' => (
     is       => 'rw',
@@ -21,21 +16,10 @@ has 'outfile' => (
         my ($self) = @_;
         my $o = $self->bamfile;
         $o =~ s/\.bam/\.tr\.bam/;
-        $o =~ s/\.cram/\.tr\.cram/;
         return $o;
     }
 );
 
-has '_file_extension' => ( is => 'rw', isa => 'Str', lazy => 1, builder => '_build__file_extension' );
-has 'extension_to_output_switch' => ( is => 'rw', isa => 'HashRef', default => sub{ {cram => '-C', bam => '-b'} } );
-
-sub _build__file_extension
-{
-  my ($self) = @_;
-  my($filename, $dirs, $suffix) = fileparse($self->bamfile,qr/[^.]*/);
-  return lc($suffix);
-}
-
 sub add_tags_to_seq {
     my ($self) = @_;
 
@@ -44,19 +28,14 @@ sub add_tags_to_seq {
     my $outfile   = $self->outfile;
 
     #open temp file in SAM format and output headers from current BAM to it
-    my @now = localtime();
-    my $timeStamp = sprintf("%04d%02d%02d%02d%02d%02d",
-                        $now[5]+1900, $now[4]+1, $now[3],
-                        $now[2],      $now[1],   $now[0]);
-    my $tmp_sam = "tmp.$timeStamp.sam";
-    print STDERR "Reading ".uc($self->_file_extension)." header\n" if($self->verbose);
-    system($self->samtools_exec." view -H $filename > $tmp_sam");
-    open( TMPFILE, ">>$tmp_sam" );
+    print STDERR "Reading BAM header\n";
+    system("samtools view -H $filename > tmp.sam");
+    open( TMPFILE, '>>tmp.sam' );
 
     #open BAM file
-    print STDERR "Reading ".uc($self->_file_extension)." file\n" if($self->verbose);
-    my $pars = Bio::Tradis::Parser::Bam->new( file => $filename, samtools_exec => $self->samtools_exec );
-    my $read_info = $pars->read_info;
+    print STDERR "Reading BAM file\n";
+    my $pars = Bio::Tradis::Parser::Bam->new( file => $filename );
+	my $read_info = $pars->read_info;
 
     while ( $pars->next_read ) {
         my $read_info = $pars->read_info;
@@ -101,7 +80,7 @@ sub add_tags_to_seq {
 
         }
         else {
-			#print STDERR "$line\n" if(!defined($tqtag));
+			print STDERR "$line\n" if(!defined($tqtag));
             $seq_tagged  = $trtag . $seq_tagged;
             $qual_tagged = $tqtag . $qual_tagged;
         }
@@ -126,10 +105,8 @@ sub add_tags_to_seq {
     close TMPFILE;
 
     #convert tmp.sam to bam
-    print STDERR "Convert SAM to ".uc($self->_file_extension)."\n" if($self->verbose);
-    
-    
-    system($self->samtools_exec." view -h -S ".$self->_output_switch." -o $outfile $tmp_sam");
+    print STDERR "Convert SAM to BAM\n";
+    system("samtools view -S -b -o $outfile tmp.sam");
 
     if ( $self->_number_of_lines_in_bam_file($outfile) !=
         $self->_number_of_lines_in_bam_file($filename) )
@@ -139,26 +116,13 @@ sub add_tags_to_seq {
     }
 
     #remove tmp file
-    unlink("$tmp_sam");
+    unlink("tmp.sam");
     return 1;
 }
 
-sub _output_switch
-{
-  my ( $self ) = @_;
-  if(defined($self->extension_to_output_switch->{$self->_file_extension}))
-  {
-    return $self->extension_to_output_switch->{$self->_file_extension};
-  }
-  else
-  {
-    return '';
-  }
-}
-
 sub _number_of_lines_in_bam_file {
     my ( $self, $filename ) = @_;
-    open( my $fh, '-|', $self->samtools_exec." view $filename | wc -l" )
+    open( my $fh, '-|', "samtools view $filename | wc -l" )
       or die "Couldn't open file :" . $filename;
     my $number_of_lines_in_file = <$fh>;
     $number_of_lines_in_file =~ s!\W!!gi;
@@ -173,56 +137,27 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Bio::Tradis::AddTagsToSeq - Takes a BAM file and creates a new BAM with tr and tq tags added to the sequence and quality strings.
+Bio::Tradis::AddTagsToSeq - Add tags to the start of the sequences
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
-Bio::Tradis::AddTagsToSeq parses BAM files, adds given tags to the start of the sequence and creates temporary SAM file,
-which is then converted to BAM
+Parses BAM files, adds given tags to the start of the sequence and creates temporary SAM file. 
+Then converts to BAM and removes the tmp SAM file.
 
    use Bio::Tradis::AddTagsToSeq;
    
    my $pipeline = Bio::Tradis::AddTagsToSeq->new(bamfile => 'abc');
    $pipeline->add_tags_to_seq();
 
-=head1 NAME
-
-Bio::Tradis::AddTagsToSeq
-
-=head1 PARAMETERS
-
-=head2 Required
-
-C<bamfile> - path to/name of file containing reads and tags
-
-=head2 Optional
-
-C<outfile> - name to assign to output BAM. Defaults to C<file.tr.bam> for an input file named C<file.bam>
-
-=head1 METHODS
-
-C<add_tags_to_seq> - add TraDIS tags to reads. For unmapped reads, the tag
-				  is added to the start of the read sequence and quality
-				  strings. For reads where the flag indicates that it is
-				  mapped and reverse complemented, the reverse complemented
-				  tags are added to the end of the read strings.
-				  This is because many conversion tools (e.g. picard) takes
-				  the read orientation into account and will re-reverse the
-				  mapped/rev comp reads during conversion, leaving all tags
-				  in the correct orientation at the start of the sequences
-				  in the resulting FastQ file.
-
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
