@@ -1,5 +1,5 @@
 package Bio::Tradis::CommandLine::CheckTags;
-$Bio::Tradis::CommandLine::CheckTags::VERSION = '1.4.3';
+
 # ABSTRACT: Check for presence of tr tag in BAM file
 
 
@@ -12,25 +12,22 @@ has 'args'        => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'script_name' => ( is => 'ro', isa => 'Str',      required => 1 );
 has 'bamfile'        => ( is => 'rw', isa => 'Str', required => 0 );
 has 'help'        => ( is => 'rw', isa => 'Bool', required => 0 );
-has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 
 sub BUILD {
     my ($self) = @_;
     
     my (
-        $bamfile,	$help, $samtools_exec
+        $bamfile,	$help
     );
 
     GetOptionsFromArray(
         $self->args,
         'b|bamfile=s'                     => \$bamfile,
-		'h|help'                           => \$help,
-		'samtools_exec=s'   => \$samtools_exec,
+		'h|help'                           => \$help
     );
 	
     $self->bamfile(abs_path($bamfile))                   if ( defined($bamfile) );
 	$self->help($help)                                   if ( defined($help) );
-	    $self->samtools_exec($samtools_exec) if ( defined($samtools_exec) );
 
 	# print usage text if required parameters are not present
 	($bamfile) or die $self->usage_text;
@@ -40,10 +37,11 @@ sub run {
 	my ($self) = @_;
 	
 	if ( defined( $self->help ) ) {
+    #if ( scalar( @{ $self->args } ) == 0 ) {
           $self->usage_text;
     }
 	
-	my $tagcheck = Bio::Tradis::DetectTags->new(bamfile => $self->bamfile, samtools_exec => $self->samtools_exec );
+	my $tagcheck = Bio::Tradis::DetectTags->new(bamfile => $self->bamfile);
 	print $tagcheck->tags_present . "\n";
 }
 
@@ -68,15 +66,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::CommandLine::CheckTags - Check for presence of tr tag in BAM file
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -84,7 +80,7 @@ Check for presence of tr tag in BAM file
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
