@@ -1,5 +1,5 @@
 package Bio::Tradis::CommandLine::PlotTradis;
-$Bio::Tradis::CommandLine::PlotTradis::VERSION = '1.4.3';
+
 # ABSTRACT: Generate plots as part of a tradis analysis
 
 
@@ -24,7 +24,7 @@ sub BUILD {
         $self->args,
         'f|mappedfile=s' => \$mappedfile,
         'o|outfile=s'    => \$outfile,
-        'm|mapping_score=i' => \$mapping_score,
+        'm|mapping_score' => \$mapping_score,
         'h|help'         => \$help
     );
 
@@ -76,15 +76,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::CommandLine::PlotTradis - Generate plots as part of a tradis analysis
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -93,7 +91,7 @@ a reference in GFF format
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
