@@ -1,5 +1,5 @@
 package Bio::Tradis::CommandLine::RemoveFastqTags;
-$Bio::Tradis::CommandLine::RemoveFastqTags::VERSION = '1.4.3';
+
 # ABSTRACT: Remove given tags from the start of the sequence
 
 
@@ -82,15 +82,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::CommandLine::RemoveFastqTags - Remove given tags from the start of the sequence
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -98,7 +96,7 @@ Removes tags from the sequence and quality strings
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
