@@ -1,5 +1,5 @@
 package Bio::Tradis::CommandLine::TradisBam;
-$Bio::Tradis::CommandLine::TradisBam::VERSION = '1.4.5';
+
 # ABSTRACT: Adds tags to sequences if tags are present
 
 
@@ -16,38 +16,29 @@ has 'outfile'     => (
     is       => 'rw',
     isa      => 'Str',
     required => 0,
+    default  => sub {
+        my $o = $self->bamfile;
+        $o =~ s/\.bam/\.tr\.bam/;
+        return $o;
+    }
 );
 has 'help' => ( is => 'rw', isa => 'Bool', required => 0 );
-has 'verbose'       => ( is => 'rw', isa => 'Bool', default => 0 );
-has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 
 sub BUILD {
     my ($self) = @_;
 
-    my ( $bamfile, $help, $outfile, $verbose, $samtools_exec );
+    my ( $bamfile, $help, $outfile );
 
     GetOptionsFromArray(
         $self->args,
         'b|bamfile=s' => \$bamfile,
         'o|outfile=s' => \$outfile,
-        'h|help'      => \$help,
-        'v|verbose'         => \$verbose,
-        'samtools_exec=s'   => \$samtools_exec,
+        'h|help'      => \$help
     );
 
     $self->bamfile( abs_path($bamfile) ) if ( defined($bamfile) );
-    if (defined($outfile)) {
-        $self->outfile( abs_path($outfile) )
-    }
-    else {
-        my $o = $self->bamfile;
-        $o =~ s/\.bam/\.tr\.bam/;
-        $self->outfile( abs_path($o) );
-    }
-
+    $self->outfile( abs_path($outfile) ) if ( defined($outfile) );
     $self->help($help)                   if ( defined($help) );
-    $self->verbose($verbose)             if ( defined($verbose) );
-    $self->samtools_exec($samtools_exec) if ( defined($samtools_exec) );
 
 	# print usage text if required parameters are not present
 	($bamfile) or die $self->usage_text;
@@ -57,20 +48,16 @@ sub run {
     my ($self) = @_;
 
     if ( defined( $self->help ) ) {
+    #if ( scalar( @{ $self->args } ) == 0 ) {
         $self->usage_text;
     }
 
     my $is_tradis =
-      Bio::Tradis::DetectTags->new( 
-        bamfile       => $self->bamfile, 
-        samtools_exec => $self->samtools_exec 
-      )->tags_present;
+      Bio::Tradis::DetectTags->new( bamfile => $self->bamfile )->tags_present;
     if ( defined($is_tradis) && $is_tradis == 1 ) {
         my $add_tag_obj = Bio::Tradis::AddTagsToSeq->new(
-            bamfile       => $self->bamfile,
-            outfile       => $self->outfile,
-            verbose       => $self->verbose,
-            samtools_exec => $self->samtools_exec
+            bamfile => $self->bamfile,
+            outfile => $self->outfile
         );
         $add_tag_obj->add_tags_to_seq;
     }
@@ -86,7 +73,7 @@ Usage: bam_to_tradis_bam -b file.bam [options]
 Options:
 -b  : bam file
 -o  : output BAM name (optional. default: <file>.tr.bam)
--v  : verbose debugging output
+
 USAGE
     exit;
 }
@@ -99,15 +86,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::CommandLine::TradisBam - Adds tags to sequences if tags are present
 
 =head1 VERSION
 
-version 1.4.5
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -116,7 +101,7 @@ with tags attached
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
