@@ -1,29 +1,21 @@
 package Bio::Tradis::DetectTags;
-$Bio::Tradis::DetectTags::VERSION = '1.4.3';
+
 # ABSTRACT: Detect tr tags in BAM file
 
 
 use Moose;
-use Bio::Tradis::Parser::Bam
+use Bio::DB::Sam;
 
 has 'bamfile' => ( is => 'ro', isa => 'Str', required => 1 );
-has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 
 sub tags_present {
     my ($self) = @_;
-    my $pars = Bio::Tradis::Parser::Bam->new( file => $self->bamfile, samtools_exec => $self->samtools_exec );
-    my $read_info = $pars->read_info;
-    $pars->next_read;
-    $read_info = $pars->read_info;
-    if(defined(${$read_info}{tr}))
-    {
-      return 1;
-    }
-    else
-    { 
-      return 0;
-    }
-    
+    my $bam    = Bio::DB::Bam->open( $self->bamfile );
+    my $header = $bam->header;
+    my $a      = $bam->read1;
+    my $tr     = $a->get_tag_values('tr');
+    if   ( defined($tr) ) { return 1; }
+    else                  { return 0; }
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -34,15 +26,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::DetectTags - Detect tr tags in BAM file
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -52,23 +42,9 @@ Detects presence of tr/tq tags in BAM files from Tradis analyses
    my $pipeline = Bio::Tradis::DetectTags->new(bamfile => 'abc');
    $pipeline->tags_present();
 
-=head1 NAME
-
-Bio::Tradis::DetectTags
-
-=head1 PARAMETERS
-
-=head2 Required
-
-C<bamfile> - path to/name of file to check
-
-=head1 METHODS
-
-C<tags_present> - returns true if TraDIS tags are detected in C<bamfile>
-
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
