@@ -1,11 +1,10 @@
 package Bio::Tradis::Parser::Bam;
-$Bio::Tradis::Parser::Bam::VERSION = '1.4.3';
+
 # ABSTRACT: Very basic BAM parser. Limited functionality.
 
 
 use Moose;
 
-has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 has 'file' => ( is => 'rw', isa => 'Str', required => 1 );
 has '_bam_handle' => (
     is       => 'ro',
@@ -27,7 +26,7 @@ sub _build__bam_handle {
     my ($self) = @_;
     my $bamfile = $self->file;
 
-    open( my $bamh, "-|", $self->samtools_exec." view $bamfile" )
+    open( my $bamh, "-|", "samtools view $bamfile" )
       or die "Cannot open $bamfile";
     return $bamh;
 }
@@ -74,7 +73,7 @@ sub seq_info {
     my $bamfile = $self->file;
 
     my ( %all_seq_info, $seq_name, %this_seq_info );
-    open( SINFO, "-|", $self->samtools_exec." view -H $bamfile | grep ^\@SQ | cut -f 2-" );
+    open( SINFO, "-|", "samtools view -H $bamfile | grep ^\@SQ | cut -f 2-" );
     while ( my $line = <SINFO> ) {
         chomp($line);
         my @fields = split( '\t', $line );
@@ -149,15 +148,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::Parser::Bam - Very basic BAM parser. Limited functionality.
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -206,7 +203,7 @@ complemented. Returns 0 or 1.
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
