@@ -1,5 +1,5 @@
 package Bio::Tradis::Parser::Fastq;
-$Bio::Tradis::Parser::Fastq::VERSION = '1.4.3';
+
 # ABSTRACT: Basic FastQ parser.
 
 
@@ -83,22 +83,19 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::Parser::Fastq - Basic FastQ parser.
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
 Parses fastq files. 
+use Bio::Tradis::Parser::Fastq;
 
-   use Bio::Tradis::Parser::Fastq;
-   
    my $pipeline = Bio::Tradis::Parser::Fastq->new(file => 'abc');
    $pipeline->next_read;
    $pipeline->read_info;
@@ -115,7 +112,7 @@ Returns an array of info for the read in an array.
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
