@@ -1,5 +1,5 @@
 package Bio::Tradis::RemoveTags;
-$Bio::Tradis::RemoveTags::VERSION = '1.4.3';
+
 # ABSTRACT: Remove tags from seqs a fastq file
 
 
@@ -87,15 +87,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::RemoveTags - Remove tags from seqs a fastq file
 
 =head1 VERSION
 
-version 1.4.3
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -108,35 +106,9 @@ Outputs a file *.rmtag.fastq unless an out file is specified
    my $pipeline = Bio::Tradis::RemoveTags->new(fastqfile => 'abc', tag => 'abc');
    $pipeline->remove_tags();
 
-=head1 PARAMETERS
-
-=head2 Required
-
-=over
-
-=item * C<fastqfile> - path to/name of file to filter
-
-=item * C<tag> - TraDIS tag to remove
-
-=back
-
-=head2 Optional
-
-=over
-
-=item * C<mismatch> - number of mismatches to allow when removing the tag. Default = 0
-
-=item * C<outfile> - defaults to C<file.rmtag.fastq> for and input file named C<file.fastq>
-
-=back
-
-=head1 METHODS
-
-C<remove_tags> - output all reads with the tags removed to C<outfile>
-
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
