@@ -1,5 +1,5 @@
 package Bio::Tradis::TradisPlot;
-$Bio::Tradis::TradisPlot::VERSION = '1.4.5';
+
 # ABSTRACT: Generate plots as part of a tradis analysis
 
 
@@ -32,15 +32,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Bio::Tradis::TradisPlot - Generate plots as part of a tradis analysis
 
 =head1 VERSION
 
-version 1.4.5
+version 1.132140
 
 =head1 SYNOPSIS
 
@@ -52,29 +50,9 @@ in GFF format
    my $pipeline = Bio::Tradis::TradisPlot->new(mappedfile => 'abc');
    $pipeline->plot();
 
-=head1 PARAMETERS
-
-=head2 Required
-
-C<mappedfile> - mapped and sorted BAM file
-
-=head2 Optional
-
-=over
-
-=item * C<outfile> - base name to assign to the resulting insertion site plot. Default = tradis.plot
-
-=item * C<mapping_score> - cutoff value for mapping score. Default = 30
-
-=back
-
-=head1 METHODS
-
-C<plot> - create insertion site plots for reads in `mappedfile`. This file will be readable by the L<Artemis genome browser|http://www.sanger.ac.uk/resources/software/artemis/>
-
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
